"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("custom-event-polyfill");
var RendererType_1 = require("../../models/RendererType");
var SearchResultsRendererService = /** @class */ (function () {
    function SearchResultsRendererService() {
        this.SEARCH_CHANGED_EVENT_NAME = 'pnp-spfx-search-changed';
        this.SEARCH_RESULT_RENDERERS_OBJECT_NAME = 'pnp-spfx-search-result-renderers';
        this.SEARCH_REFINER_RENDERERS_OBJECT_NAME = 'pnp-spfx-search-refiner-renderers';
        this.SEARCH_VERTICAL_RENDERERS_OBJECT_NAME = 'pnp-spfx-search-vertical-renderers';
        this.SEARCH_PAGINATION_RENDERERS_OBJECT_NAME = 'pnp-spfx-search-pagination-renderers';
    }
    Object.defineProperty(SearchResultsRendererService.prototype, "results", {
        get: function () {
            return this.searchResults;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SearchResultsRendererService.prototype, "IsLoading", {
        get: function () {
            return this.isLoading;
        },
        set: function (status) {
            this.isLoading = status;
        },
        enumerable: true,
        configurable: true
    });
    SearchResultsRendererService.prototype.updateResultData = function (results, rendererId, mountNode, customTemplateFieldValues) {
        this.searchResults = results;
        var searchEvent = new CustomEvent(this.SEARCH_CHANGED_EVENT_NAME);
        searchEvent.rendererId = rendererId;
        searchEvent.results = results;
        searchEvent.mountNode = mountNode;
        searchEvent.customTemplateFieldValues = customTemplateFieldValues;
        window.dispatchEvent(searchEvent);
    };
    SearchResultsRendererService.prototype.registerRenderer = function (rendererId, rendererName, rendererIcon, rendererType, callback, requiredSelectProperties, fields) {
        var _this = this;
        var newRenderer = {
            customFields: fields,
            icon: rendererIcon,
            id: rendererId,
            name: rendererName,
            selectProperties: requiredSelectProperties,
            type: rendererType,
        };
        switch (rendererType) {
            case RendererType_1.RendererType.SearchResults:
                this.setRenderer(this.SEARCH_RESULT_RENDERERS_OBJECT_NAME, newRenderer);
                break;
            case RendererType_1.RendererType.SearchRefiners:
                this.setRenderer(this.SEARCH_REFINER_RENDERERS_OBJECT_NAME, newRenderer);
                break;
            case RendererType_1.RendererType.SearchVerticals:
                this.setRenderer(this.SEARCH_VERTICAL_RENDERERS_OBJECT_NAME, newRenderer);
                break;
            case RendererType_1.RendererType.SearchPagination:
                this.setRenderer(this.SEARCH_PAGINATION_RENDERERS_OBJECT_NAME, newRenderer);
                break;
            default:
                break;
        }
        addEventListener(this.SEARCH_CHANGED_EVENT_NAME, function (e) { return _this.handleNewDataRegistered(e, rendererId, callback); });
    };
    SearchResultsRendererService.prototype.getRegisteredRenderers = function (rendererType) {
        switch (rendererType) {
            case RendererType_1.RendererType.SearchResults:
                return window[this.SEARCH_RESULT_RENDERERS_OBJECT_NAME];
            case RendererType_1.RendererType.SearchRefiners:
                return window[this.SEARCH_REFINER_RENDERERS_OBJECT_NAME];
            case RendererType_1.RendererType.SearchVerticals:
                return window[this.SEARCH_VERTICAL_RENDERERS_OBJECT_NAME];
            case RendererType_1.RendererType.SearchPagination:
                return window[this.SEARCH_PAGINATION_RENDERERS_OBJECT_NAME];
            default:
                break;
        }
    };
    SearchResultsRendererService.prototype.setRenderer = function (rendererWindowObjectName, newRenderer) {
        if (window[rendererWindowObjectName] === undefined) {
            window[rendererWindowObjectName] = newRenderer;
        }
        else {
            window[rendererWindowObjectName].push(newRenderer);
        }
    };
    SearchResultsRendererService.prototype.handleNewDataRegistered = function (e, rendererId, callback) {
        if (callback) {
            if (e.rendererId === rendererId) {
                callback(e);
            }
        }
    };
    return SearchResultsRendererService;
}());
exports.default = SearchResultsRendererService;
